############################################################
############################################################
##CODE
############################################################
############################################################

#The following code for the statistical freeware R was used in the data analyses of:
#"Miquel Ferrín, Josep Peñuelas, Albert Gargallo-Garriga, Amaia Iribar, Ivan A. Janssens, 
#Sara Marañón-Jiménez, Jérôme Murienne, Andreas Richter, Bjarni D. Sigurdsson, and Guille Peguero

#Responses of soil hexapod communities to warming are mediated by shifts in microbial carbon and nitrogen in a subarctic grassland
#_JOURNAL NAME_, revision submitted."

#Data and code, along with a ReadMe file containing descriptions of all observations, 
#have been submitted to digital data repository following the paper's acceptance.

#The persons associated with this code have dedicated the work to the public domain by 
#waiving all of their rights to the code worldwide under copyright law, including all related 
#and neighboring rights, to the extent allowed by law. You can copy, modify, distribute and use 
#the code, even for commercial purposes, all without asking permission.

#Code prepared for submission by Miquel Ferrin, 
#Autonomous University of Barcelona, CREAF-CSIC. 
#m.ferrin@creaf.uab.cat

#LAST UPDATED MARCH 2022
#R version: v4.1.1
#R Studio version: 1.4.1717
#OS: Microsoft Windows 11 Home
#PC: Asus VivoBook S14


rm(list=ls()) #clean environment
cat("\014")   #clean console
dev.off()     #clean plots

#getwd() #see your current working directory first
#setwd()

# datasets #

# datasets #
df.motus     <- read.table("Ferrinetal_motus.txt", header = T, sep = "\t")
df.metadata  <- read.table("Ferrinetal_metadata2.txt", header = T, sep = "\t")
df.comm      <- read.table("Ferrinetal_comm.txt", header = T, sep = "\t", row.names = 1)
df.var       <- read.table("Ferrinetal_metadata.txt", header = T, sep = "\t")

# Packages #
library(dplyr)
library(vegan)
library(tidyverse)
library(dplyr)
library(tidyr)

library(mixOmics)


######################
## data preparation ## 
######################
#(example with D (+3ºC) & E (+5ºC))

#df.comm per site

df.metadata$code = rownames(df.metadata)
df.motus$SELECTED.SPECIES <- gsub(" ", ".", df.motus$SELECTED.SPECIES)

df.comm.mod <- df.comm
df.comm.mod$code <- rownames(df.comm.mod)
df.comm.mod <-  gather(df.comm.mod, SELECTED.SPECIES, reads,-code)
df.comm.mod <- merge(df.comm.mod, df.motus, by = "SELECTED.SPECIES", all.x = T)
df.comm.mod <- merge(df.comm.mod, df.metadata, by = "code", all.x = T) %>% 
  dplyr::select(code, reads, SELECTED.SPECIES, Site, Temperature)
df.comm.mod <- df.comm.mod[!duplicated(df.comm.mod), ]
df.comm.mod <- df.comm.mod %>% arrange(SELECTED.SPECIES)

df.comm.de <- df.comm.mod %>% filter(Temperature != "A")
df.comm.de$Site <- NULL
df.comm.de <- as.tibble(df.comm.de)
df.comm.de <- spread(df.comm.de, SELECTED.SPECIES, reads)
df.comm.de <- df.comm.de %>% column_to_rownames(var = "code")
colnames(df.comm.de[, colSums(df.comm.de != "0") == 0])
df.comm.de <- df.comm.de[, colSums(df.comm.de != "0") != 0]
df.comm.de <- df.comm.de[rowSums(df.comm.de != "0") != 0,]

#df.motus per site

df.motus.de <- df.motus
df.motus.de <- df.motus.de[ rownames(df.motus.de) %in% colnames(df.comm.de), ] 
df.motus.de <- df.motus.de %>% arrange(SELECTED.SPECIES)

#df.metadata per Site

df.metadata.de <- df.metadata %>% filter(Temperature != "A")
df.comm.de$plot <- rownames(df.comm.de)
df.metadata.de$plot <- rownames(df.metadata.de)
df.metadata.de <- merge(df.metadata.de, df.comm.de, by = "plot", all.x = T) %>% 
  column_to_rownames("plot") %>% 
  na.omit() %>%
  dplyr::select("SampleNumber", "Replicate", "Site", "Temperature.x", "Season", "Weight") %>% 
  dplyr::rename(., Temperature = Temperature.x)
df.metadata.de$plot <- rownames(df.metadata.de)
df.comm.de <- merge(df.metadata.de, df.comm.de, by = "plot", all.x = T) %>% 
  column_to_rownames("plot") %>% 
  dplyr::select(-(1:6)) %>% na.omit()

df.metadata.de$code <- rownames(df.metadata.de)
df.comm.de <- df.comm.de %>% 
  mutate(code = rownames(.)) %>% 
  merge(., df.metadata.de, by = "code", all.x = T) %>% 
  mutate(X = paste(Site, Replicate, Temperature, sep = '')) %>% 
  group_by(X, Temperature) %>%
  dplyr::select(-c(27:33)) %>% 
  dplyr::select(-code) %>% 
  summarise_at(., vars(,2:25), funs(mean(., na.rm=TRUE))) %>%
  as.data.frame(.)

df.comm.de <- df.comm.de[, colSums(df.comm.de != 0) > 0]
rownames(df.comm.de) <- df.comm.de$X
df.comm.de$X <- NULL

df.metadata.de <- df.comm.de$Temperature
df.comm.de$Temperature <- NULL


#############
## sPLS-DA ## 
#############

# Packages #
library(mixOmics)

#DATA PREPARATION
vector.y <- as.factor(df.metadata.de) #creating the vector for trt
X <- as.matrix(df.comm.de)
Y <- vector.y
summary(Y) ## class summary
dim(X) ## number of samples and features
length(Y) ## length of class membership factor = number of samples

set.seed(1234) # for reproductility in this vignette, otherwise increase nrepeat

list.keepX <- c(5:15)
list.keepX 

set.seed(1234)

tune.splsda.srbct <- tune.splsda(X, Y, ncomp = 4, 
                                 validation = 'Mfold',
                                 folds = 3, dist = 'max.dist', progressBar = T,
                                 measure = "BER", test.keepX = list.keepX,
                                 nrepeat = 50)

ncomp <- tune.splsda.srbct$choice.ncomp$ncomp 
select.keepX <- tune.splsda.srbct$choice.keepX[1:ncomp]
MyResult.splsda.final <- splsda(X, Y, ncomp = 2, keepX = select.keepX)
MyResult.splsda.final[["prop_expl_var"]][["X"]][["comp1"]] #explained variance

plotIndiv(MyResult.splsda.final, ind.names = FALSE, legend=TRUE,
          ellipse = TRUE, title="sPLS-DA - final result")
plotLoadings(MyResult.splsda.final, contrib = 'max', method = 'mean', comp = ncomp)

#ROC
auc.plsda <- auroc(MyResult.splsda.final, roc.comp = 1)
auroc(MyResult.splsda.final, roc.comp = 2) #p-value


#Variable selection outputs
selectVar(MyResult.splsda.final, comp=1)$value
plotLoadings(MyResult.splsda.final, contrib = 'max', method = 'mean', comp = 1)
contri.n.trt.c1 <- plotLoadings(MyResult.splsda.final, contrib = 'max', method = 'mean', comp = 1)
contri.n.comp <- MyResult.splsda.final[["loadings.star"]][[1]]

################
## REGRESSION ## 
################

X.VAR.de <- as.data.frame(MyResult.splsda.final[["variates"]][["X"]])

df.var.de <- df.var %>% 
  filter( trt != "A") %>% 
  dplyr::select(X, trt, Ts10_MAT, M_DOC, M_DON, 
                M_Cmic, M_Nmic)

df.var.de <- X.VAR.de %>% 
  dplyr::select(comp1) %>% 
  mutate(X = rownames(.)) %>% 
  group_by(X) %>%
  summarise_at(., vars(comp1), funs(mean(., na.rm=TRUE))) %>%
  as.data.frame(.) %>% 
  merge(., df.var.de, by = "X", all.x = T)

df.var.de.s <- df.var.de
df.var.de.s[,5:8] <- as.data.frame(scale(df.var.de[,5:8]))
df.var.de.s <- df.var.de.s %>% gather(., key="variable", value="score", 5:8)

ggplot(df.var.de.s, aes(comp1, score, colour = variable)) +
  geom_point(size = 3, aes(colour = factor(variable))) +
  geom_smooth(se = FALSE, method = lm) +  
  scale_color_manual(values=c("#999999", "#CC33CC", "#56B4E9", "black")) +
  theme_bw() +
  xlim(-3, 3)


#########
## END ##
#########
